
# Solvers (Internal)

```{eval-rst}
.. currentmodule:: pySPFM._solvers

.. autosummary::
   :toctree: ../generated/
   :template: module.rst

   debiasing
   fista
   hrf_generator
   lars
   select_lambda
   spatial_regularization
   stability_selection
```
